@@ -32,7 +32,8 @@ class BaseHandler(tornado.web.RequestHandler):
         self.logger = logging
         self.ua = self.request.headers.get('User-Agent', '')
         self.referer = self.request.headers.get('Referer', '')
-        self.host = self.request.headers.get('Host', '')
+        self.host = self.request.headers.get('Host', self.request.host)
+        self.scheme = self.request.headers.get('Scheme', self.request.protocol)
 
     def _request_summary(self):
         return f"{self.request.method} {self.request.uri} ({self.referer})"
@@ -110,11 +111,8 @@ class BaseHandler(tornado.web.RequestHandler):
 
     @cached_property
     def weixin(self):
-        if self.get_argument('f', None) == 'weixin':
-            return True
-        else:
-            weixin_re = re.compile(r'MicroMessenger', re.I)
-            return True if weixin_re.search(self.ua) else False
+        weixin_re = re.compile(r'MicroMessenger', re.I)
+        return True if weixin_re.search(self.ua) else False
 
     @cached_property
     def cache_key(self):
