@@ -83,22 +83,27 @@ class BaseHandler(BaseHandler):
         ret = resp.json()
         if not ret.err:
             user = await awaitable(self.db.users.find_one({'openId': ret.openId}))
-            ret.token = self.current_user.token
-            if not user:
-                user = ret
+            if user:
+                ret = user
+                # if self.current_user and self.current_user._id != user._id:
+                #    return {'err': 2, 'msg': f'该微信号已绑定用户{user.id}'}
+            else:
                 if self.current_user:
                     ret.active = True
+                    ret.token = self.current_user.token
                     await awaitable(self.db.users.update_one({'_id': self.current_user._id}, {'$set': ret}))
                 else:
-                    user.id = await awaitable(self.db.users.seq_id)
-                    user.token = uuid.uuid4().hex
-                    user.active = True
-                    user.created_at = datetime.datetime.now().replace(microsecond=0)
-                    await awaitable(self.db.users.insert_one(user))
-            elif self.current_user and self.current_user._id != user._id:
-                return {'err': 2, 'msg': f'该微信号已绑定用户{user.id}'}
+                    ret.id = await awaitable(self.db.users.seq_id)
+                    ret.token = uuid.uuid4().hex
+                    ret.active = True
+                    ret.created_at = datetime.datetime.now().replace(microsecond=0)
+                    ret.vip = 3
+                    ret.vip1_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    ret.vip2_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    ret.vip3_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    await awaitable(self.db.users.insert_one(ret))
             expires = datetime.datetime.now() + datetime.timedelta(days=30)
-            self.set_cookie('token', user.token, expires=expires)
+            self.set_cookie('token', ret.token, expires=expires)
             ret.err = 0
 
         return ret
